Wisconsin Court System -

skip navigation
contact the court
directories
employment
news

###### Wisconsin Court System

overview supreme court court of appeals circuit courts municipal courts administrative offices committees and boards programs educational resources history
circuit court supreme court pending supreme court and
court of appeals
supreme court court of appeals
supreme court circuit court
circuit court court of appeals office of lawyer regulation board of bar examiners
for the public for jurors for attorneys for judges for commissioners for interpreters for volunteers for veterans
pay fees/fines online forms assistant online juror services circuit court eFiling appellate court eFiling cle reporting
guides reports fees and forfeitures newsletters speeches statistics

Page 1 of 31 Search again Next > >| | Go to page

Release date | Docket number | Caption | Mark/view
Mar 13, 2012 | 2009AP001643-CR | State v. William Dinkins, Sr. | HTML PDF
Mar 08, 2012 | 2011AP000987 | Ted Nickel v. United States of America | HTML PDF
Mar 08, 2012 | 2010AP001391-CRNM | State v. Jeffery G. Sutton | HTML PDF
Mar 07, 2012 | 2009AP002848 | Lindy Orlowski v. State Farm Mutual Automobile Insurance Company | HTML PDF
Mar 06, 2012 | 2009AP002768 | Joel Hirschhorn v. Auto-Owners Insurance Company | HTML PDF
Mar 01, 2012 | 2011AP002326-D | Office of Lawyer Regulation v. Tracy R. Eichhorn-Hicks | HTML PDF
Mar 01, 2012 | 2010AP002538-D | Office of Lawyer Regulation v. Donald Hahnfeld | HTML PDF
Mar 01, 2012 | 2002AP002962-D | Office of Lawyer Regulation v. Jane Edgar | HTML PDF
Mar 01, 2012 | 1999AP000062-D | BAPR v. Jane A. Edgar | HTML PDF
Feb 28, 2012 | 2009AP003075 | State v. Basil E. Ryan, Jr. | HTML PDF
Feb 24, 2012 | 2008AP001830 | MBS-Certified Public Accountants, LLC v. Wisconsin Bell Inc. | HTML PDF
Feb 14, 2012 | 2010AP000772-CR | State v. Carl L. Dowdy | HTML PDF
Feb 10, 2012 | 2011AP002448-D | Office of Lawyer Regulation v. Michael J. Hicks | HTML PDF
Feb 10, 2012 | 2011AP001073-D | Office of Lawyer Regulation v. Arik J. Guenther | HTML PDF
Feb 09, 2012 | 2011AP002263-D | Office of Lawyer Regulation v. Katharine L. Taber | HTML PDF
Feb 09, 2012 | 2011AP001700-D | Office of Lawyer Regulation v. Warren L. Brandt | HTML PDF
Feb 08, 2012 | 2010AP002398 | Loran B. Zwiefelhofer v. Town of Cooks Valley | HTML PDF
Feb 03, 2012 | 2011AP002625-D | Office of Lawyer Regulation v. Mark Milos | HTML PDF
Feb 01, 2012 | 2010AP000445-CR | State v. Sharon A. Sellhausen | HTML PDF
Feb 01, 2012 | 2008AP002759-CR | State v. Daniel H. Hanson | HTML PDF
Jan 31, 2012 | 2009AP002385 | Todd Olson v. Robert Farrar | HTML PDF
Dec 23, 2011 | 2010AP001113-CR | State v. Jason E. Goss | HTML PDF
Dec 22, 2011 | 2009AP001557 | 260 North 12th Street, LLC v. State of Wisconsin Department of Transportation | HTML PDF
Dec 20, 2011 | 2011AP000960-D | Office of Lawyer Regulation v. Robert J. Smead | HTML PDF
Dec 16, 2011 | 2011AP000049-D | Office of Lawyer Regulation v. William R. Lamb | HTML PDF
Dec 07, 2011 | 2010AP003012-D | Office of Lawyer Regulation v. Michael J. Pierski | HTML PDF
Nov 04, 2011 | 2011AP000047-D | Office of Lawyer Regulation v. Ronald K. Niesen | HTML PDF
Nov 04, 2011 | 2008AP002337-D | Office of Lawyer Regulation v. Alexis L. Michael | HTML PDF
Nov 01, 2011 | 2010AP000387-CR | State v. Gregory K. Nielsen | HTML PDF
Nov 01, 2011 | 2009AP002422-CR | State v. David W. Domke | HTML PDF
Oct 05, 2011 | 2011AP001193-D | Office of Lawyer Regulation v. Ronald L. Brandt | HTML PDF
Oct 05, 2011 | 2011AP001139-D | Office of Lawyer Regulation v. Craig M. Hunt | HTML PDF
Sep 20, 2011 | 2011AP001509-D | Office of Lawyer Regulation v. Eric Arthur Forstrom | HTML PDF
Sep 20, 2011 | 1997AP000457-D | OLR v. Thomas E. Warmington | HTML PDF
Aug 26, 2011 | 2010AP000112-D | Lawyer Regulation System of the State of Wisconsin v. Michael O. Erspamer | HTML PDF
Jul 26, 2011 | 2010AP001142 | State v. Glen D. Nordberg | HTML PDF
Jul 26, 2011 | 2009AP001579 | State v. Edwin Clarence West | HTML PDF
Jul 22, 2011 | 2009AP000191 | Stupar River LLC v. Town of Linwood Board of Review | HTML PDF
Jul 19, 2011 | 2009AP001470 | Covenant Healthcare System, Inc. v. City of Wauwatosa | HTML PDF
Jul 19, 2011 | 2009AP001469 | Covenant Healthcare System, Inc. v. City of Wauwatosa | HTML PDF
Jul 19, 2011 | 2009AP001351-CR | State v. Gregg B. Kandutsch | HTML PDF
Jul 19, 2011 | 2009AP000472 | State v. David J. Balliette | HTML PDF
Jul 19, 2011 | 2009AP000120 | Dale Dawson v. Town of Jackson | HTML PDF
Jul 19, 2011 | 2007AP000369 | Bryan Casper v. American International South Insurance Company | HTML PDF
Jul 19, 2011 | 2006AP002512 | Bryan Casper v. American International South Insurance Company | HTML PDF
Jul 19, 2011 | 2006AP001229 | Bryan Casper v. American International South Insurance Company | HTML PDF
Jul 15, 2011 | 2011AP000048-D | Office of Lawyer Regulation v. James M. Schoenecker | HTML PDF
Jul 14, 2011 | 2010AP001939-D | Office of Lawyer Regulation v. Christopher A. Mutschler | HTML PDF
Jul 14, 2011 | 2009AP002845-W | Madison Metropolitan School District v. Circuit Court for Dane County | HTML PDF
Jul 14, 2011 | 2009AP000025-CR | State v. Olu A. Rhodes | HTML PDF

Page 1 of 31 Search again Next > >| | Go to page